==> aws-cdk.aws-batch-alpha-2.3.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_batch_alpha_ComputeResourceType(p) {
}
function _aws_cdk_aws_batch_alpha_AllocationStrategy(p) {
}
function _aws_cdk_aws_batch_alpha_LogDriver(p) {
}
function _aws_cdk_aws_batch_alpha_PlatformCapabilities(p) {
}
function _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification(p) {
}
function _aws_cdk_aws_batch_alpha_INodeRangeProps(p) {
}
function _aws_cdk_aws_batch_alpha_IMultiNodeProps(p) {
}
function _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeEnvironment))
        _aws_cdk_aws_batch_alpha_IComputeEnvironment(p.computeEnvironment);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_JobQueueProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeEnvironments))
        _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment(p.computeEnvironments);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_IComputeEnvironment(p) {
}
function _aws_cdk_aws_batch_alpha_IJobDefinition(p) {
}
function _aws_cdk_aws_batch_alpha_IJobQueue(p) {
}
function _aws_cdk_aws_batch_alpha_LogConfiguration(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.logDriver))
        _aws_cdk_aws_batch_alpha_LogDriver(p.logDriver);
    if (!visitedObjects.has(p.secretOptions))
        _aws_cdk_aws_batch_alpha_ExposedSecret(p.secretOptions);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_ComputeEnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeResources))
        _aws_cdk_aws_batch_alpha_ComputeResources(p.computeResources);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_JobDefinitionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.container))
        _aws_cdk_aws_batch_alpha_JobDefinitionContainer(p.container);
    if (!visitedObjects.has(p.nodeProps))
        _aws_cdk_aws_batch_alpha_IMultiNodeProps(p.nodeProps);
    if (!visitedObjects.has(p.platformCapabilities))
        _aws_cdk_aws_batch_alpha_PlatformCapabilities(p.platformCapabilities);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_ExposedSecret(p) {
}
function _aws_cdk_aws_batch_alpha_ComputeEnvironment(p) {
}
function _aws_cdk_aws_batch_alpha_JobQueue(p) {
}
function _aws_cdk_aws_batch_alpha_JobDefinition(p) {
}
function _aws_cdk_aws_batch_alpha_ComputeResources(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.allocationStrategy))
        _aws_cdk_aws_batch_alpha_AllocationStrategy(p.allocationStrategy);
    if (!visitedObjects.has(p.instanceTypes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_InstanceType(p.instanceTypes);
    if (!visitedObjects.has(p.launchTemplate))
        _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification(p.launchTemplate);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_batch_alpha_ComputeResourceType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_JobDefinitionContainer(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.logConfiguration))
        _aws_cdk_aws_batch_alpha_LogConfiguration(p.logConfiguration);
    if (!visitedObjects.has(p.mountPoints))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_MountPoint(p.mountPoints);
    if (!visitedObjects.has(p.ulimits))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_Ulimit(p.ulimits);
    if (!visitedObjects.has(p.volumes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_Volume(p.volumes);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_batch_alpha_ComputeResourceType, _aws_cdk_aws_batch_alpha_AllocationStrategy, _aws_cdk_aws_batch_alpha_LogDriver, _aws_cdk_aws_batch_alpha_PlatformCapabilities, _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification, _aws_cdk_aws_batch_alpha_INodeRangeProps, _aws_cdk_aws_batch_alpha_IMultiNodeProps, _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment, _aws_cdk_aws_batch_alpha_JobQueueProps, _aws_cdk_aws_batch_alpha_IComputeEnvironment, _aws_cdk_aws_batch_alpha_IJobDefinition, _aws_cdk_aws_batch_alpha_IJobQueue, _aws_cdk_aws_batch_alpha_LogConfiguration, _aws_cdk_aws_batch_alpha_ComputeEnvironmentProps, _aws_cdk_aws_batch_alpha_JobDefinitionProps, _aws_cdk_aws_batch_alpha_ExposedSecret, _aws_cdk_aws_batch_alpha_ComputeEnvironment, _aws_cdk_aws_batch_alpha_JobQueue, _aws_cdk_aws_batch_alpha_JobDefinition, _aws_cdk_aws_batch_alpha_ComputeResources, _aws_cdk_aws_batch_alpha_JobDefinitionContainer };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-batch-alpha-2.7.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_batch_alpha_ComputeResourceType(p) {
}
function _aws_cdk_aws_batch_alpha_AllocationStrategy(p) {
}
function _aws_cdk_aws_batch_alpha_LogDriver(p) {
}
function _aws_cdk_aws_batch_alpha_PlatformCapabilities(p) {
}
function _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification(p) {
}
function _aws_cdk_aws_batch_alpha_INodeRangeProps(p) {
}
function _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeEnvironment))
        _aws_cdk_aws_batch_alpha_IComputeEnvironment(p.computeEnvironment);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_IMultiNodeProps(p) {
}
function _aws_cdk_aws_batch_alpha_JobQueueProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeEnvironments))
        _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment(p.computeEnvironments);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_IComputeEnvironment(p) {
}
function _aws_cdk_aws_batch_alpha_IJobDefinition(p) {
}
function _aws_cdk_aws_batch_alpha_IJobQueue(p) {
}
function _aws_cdk_aws_batch_alpha_LogConfiguration(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.logDriver))
        _aws_cdk_aws_batch_alpha_LogDriver(p.logDriver);
    if (!visitedObjects.has(p.secretOptions))
        _aws_cdk_aws_batch_alpha_ExposedSecret(p.secretOptions);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_ComputeEnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.computeResources))
        _aws_cdk_aws_batch_alpha_ComputeResources(p.computeResources);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_JobDefinitionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.container))
        _aws_cdk_aws_batch_alpha_JobDefinitionContainer(p.container);
    if (!visitedObjects.has(p.nodeProps))
        _aws_cdk_aws_batch_alpha_IMultiNodeProps(p.nodeProps);
    if (!visitedObjects.has(p.platformCapabilities))
        _aws_cdk_aws_batch_alpha_PlatformCapabilities(p.platformCapabilities);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_ExposedSecret(p) {
}
function _aws_cdk_aws_batch_alpha_ComputeEnvironment(p) {
}
function _aws_cdk_aws_batch_alpha_JobQueue(p) {
}
function _aws_cdk_aws_batch_alpha_JobDefinition(p) {
}
function _aws_cdk_aws_batch_alpha_ComputeResources(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.allocationStrategy))
        _aws_cdk_aws_batch_alpha_AllocationStrategy(p.allocationStrategy);
    if (!visitedObjects.has(p.instanceTypes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_InstanceType(p.instanceTypes);
    if (!visitedObjects.has(p.launchTemplate))
        _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification(p.launchTemplate);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_batch_alpha_ComputeResourceType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_batch_alpha_JobDefinitionContainer(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.logConfiguration))
        _aws_cdk_aws_batch_alpha_LogConfiguration(p.logConfiguration);
    if (!visitedObjects.has(p.mountPoints))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_MountPoint(p.mountPoints);
    if (!visitedObjects.has(p.ulimits))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_Ulimit(p.ulimits);
    if (!visitedObjects.has(p.volumes))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ecs_Volume(p.volumes);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_batch_alpha_ComputeResourceType, _aws_cdk_aws_batch_alpha_AllocationStrategy, _aws_cdk_aws_batch_alpha_LogDriver, _aws_cdk_aws_batch_alpha_PlatformCapabilities, _aws_cdk_aws_batch_alpha_LaunchTemplateSpecification, _aws_cdk_aws_batch_alpha_INodeRangeProps, _aws_cdk_aws_batch_alpha_JobQueueComputeEnvironment, _aws_cdk_aws_batch_alpha_IMultiNodeProps, _aws_cdk_aws_batch_alpha_JobQueueProps, _aws_cdk_aws_batch_alpha_IComputeEnvironment, _aws_cdk_aws_batch_alpha_IJobDefinition, _aws_cdk_aws_batch_alpha_IJobQueue, _aws_cdk_aws_batch_alpha_LogConfiguration, _aws_cdk_aws_batch_alpha_ComputeEnvironmentProps, _aws_cdk_aws_batch_alpha_JobDefinitionProps, _aws_cdk_aws_batch_alpha_ExposedSecret, _aws_cdk_aws_batch_alpha_ComputeEnvironment, _aws_cdk_aws_batch_alpha_JobQueue, _aws_cdk_aws_batch_alpha_JobDefinition, _aws_cdk_aws_batch_alpha_ComputeResources, _aws_cdk_aws_batch_alpha_JobDefinitionContainer };
module.exports.DeprecationError = DeprecationError;
